@@ -6,5 +6,5 @@ from pipeline.compressors import SubProcessCompressor
 
 class CSSMinCompressor(SubProcessCompressor):
     def compress_css(self, css):
-        command = "%s %s" % (settings.PIPELINE_CSSMIN_BINARY, settings.PIPELINE_CSSMIN_ARGUMENTS)
+        command = (settings.CSSMIN_BINARY, settings.CSSMIN_ARGUMENTS)
         return self.execute_command(command, css)
