@@ -1,4 +1,13 @@
 # -*- coding: utf-8 flake8: noqa -*-
+import os
+import sys
+
+
+if sys.platform.startswith('win'):
+    os.environ.setdefault('NUMBER_OF_PROCESSORS', '1')
+
+
+from .test_collector import *
 from .test_compiler import *
 from .test_compressor import *
 from .test_template import *
@@ -7,3 +16,4 @@ from .test_middleware import *
 from .test_packager import *
 from .test_storage import *
 from .test_utils import *
+from .test_views import *
